#===============================================================================
#. Name   : Introduo ao estudo de probabilidades
# Author : Alunos curso de Cincia da Computao
# Date   : 06/08/2019 09:51:23
# Aim    : Ilustar os conceitos bsicos de probalidade com o R
# Mail   : <<<joselaudio.faria@gmail.com>>>
# Reviso: 2024-06-26 11:54:59 - J.C.Faria
#===============================================================================

#. Anlise combinatria (teoria da contagem) no R
str(combn)

# Trabalhando com letras
combn(x=letters[1:3],
      m=2)

# Pode ser passada outra funo como argumento
combn(x=letters[1:3],
      m=2,
      min) # mnimo valor de cada combinao

combn(x=letters[1:3],
      m=2,
      max) # mximo valor de cada combinao

# Trabalhando com nmeros
combn(x=4,
      m=3)

combn(x=4,
      m=3,
      min) # mnimo valor de cada combinao

combn(x=4,
      m=3,
      max) # mximo valor de cada combinao

combn(x=4,
      m=3,
      mean) # a mdia de cada combinao

# Um vetor genrico C(6, 2)
(cb <- combn(x=c(paste0('a', 1:3),
                 paste0('b', 1:2),
                 paste0('c', 1)),
             m=2))
class(cb)
dim(cb)

dim(cb)[2] # fornece o nmero de combinaes

# Anlise combinatria em funes elementares
x <- 6
m <- 2
factorial(x) / (factorial(m) * factorial(x-m))


dim(cb)[2] == factorial(6) / (factorial(2) * factorial(6-2))

#. Frequnica absoluta e relativa
# Considerando uma urna com 15 bolas numeradas de 1 a 15
set.seed(2019)
(evento <- sample(1:15,
                  100,
                  replace=T))

#... Freq. abasoluta(fi)
# nmero exato de vezes que a bola 13 foi retirada
(f <- length(evento[evento==13]))

# alternativa
(f <- sum(evento == 13))

#... Frequncia relativa
# ocorrencia da bola de nmero 13 em 100 retiradas
(fr <- f/100)

# Determinar a ocorrncia de cada valor (1..15) em %
# (forma difcil abaixo... pense numa forma mais fcil)
percent <- numeric()

for(i in 1:15){
  percent[i] <- 100* sum(evento == i)/100
}

names(percent) <- paste('b',
                        1:15,
                        sep='')
percent
sum(percent)

# Verificao
length(evento[evento==1]) == percent[1]

# Frequncia relativa decimal
(fr_d <- percent/100)
sum(fr_d)

# Frequncia %
(fr_p <- 100 * percent/100)
sum(fr_p)


#. Estabilizao da frequncia relativa com o aumento do nmero de repeties do experimento
#.. Lanamento de uma moeda
CARA <- 'c'      # Sucesso
p <- c('c', 'k') # possveis valores
n <- 1e4         # nmero de repeties do experimento

S <- sample(p,
            n,
            rep=T)

suc <- 0 # zerar varivel de contagem dos casos de sucesso
fr  <- numeric() # cria espao na memria do computador para a varivel "fr"

# Contagem da frequncia relativa
for(i in 1:n)
{
  if(S[i] == CARA)
    suc <- suc + 1

  fr[i] <- suc/i
}

str(fr)

plot(fr,
     type='l',
     col='darkblue',
     lwd=2,
     ylim=c(0, 1),
     xlab= 'Lanamento moeda',
     ylab= 'Frequncia relativa do nmero de caras (fr)')

abline(h=1/2,
       col='red',
       lwd=2)

#. Estabilizao da frequncia relativa com o aumento do nmero de repeties do experimento
#.. Lanamento de um dado
PAR <- c(2, 4, 6) # ocorrer nmero par
p <- 1:6 # possveis valores
n <- 1e4 # nmero de repeties do experimento

S <- sample(p,
            n,
            rep=T)

suc <- 0 # zerar varivel de contagem dos casos de sucesso
fr  <- numeric() # cria espao na memria do computador para a varivel "fr"

# Contagem da frequncia relativa
for(i in 1:n)
{
  if(S[i] %in% PAR)
    suc <- suc + 1

  fr[i] <- suc/i
}

str(fr)

plot(fr,
     type='l',
     col='darkblue',
     lwd=2,
     ylim=c(0, 1),
     xlab= 'Lanamento dado',
     ylab= 'Frequncia relativa dos nmeros pares (fr)')

abline(h=1/2,
       col='red',
       lwd=2)

#. Probabilidade condicional
# (usando apenas funes de baixo nvel = 'na unha')
 S <- array(dim=c(36, 2)) # cria um matriz (36 linhas e 2 colunas)
PA <- array(dim=c(3, 2))
PB <- array(dim=c(15, 2))
 k <- 0

# Combinar 2 dados
for(i in 1:6){
  for(j in 1:6){
    k <- k+1
    S[k, 1] <- i
    S[k, 2] <- j
  }
}
S

# PA = {(x1 , x2 )/ x1 + x2 = 10}
k <- 0
for(i in 1:6){
  for(j in 1:6){
    if(i+j == 10){
      k <- k+1
      PA[k, 1] <- i
      PA[k, 2] <- j
    }
  }
}
PA

# PB = {(x1 , x2 )/ x1 > x2 }
k <- 0
for(i in 1:6){
  for(j in 1:6){
    if(i > j){
      k <- k+1
      PB[k, 1] <- i
      PB[k, 2] <- j
    }
  }
}
PB

#. Independncia Estatstica
# Lote de 10 peas, 4 so defeituosas. 2 peas so retiradas uma aps a outra COM
# REPOSIO.
# A = { boa}
# B = { boa}
# verificar que A e B so independentes
# por P(B) ser igual a P(A/B)

# funo que recebe dois eventos e retorna a cardinalidade da interseco
In <- function(a, b) {
  car <- 0
  c <- length(a)/2
  d <- length(b)/2
  for (i in 1:c) {
    for (j in 1:d) {
      if (a[i, 1] == b[j, 1] && a[i, 2] == b[j, 2])
        car <- car + 1
    }
  }
  car
}

# funo que recebe dois eventos A e B, e retorna a probabilidade condicional P(A|B)
PC <- function(a, b) {
  c <- In(a, b) / (length(b) / 2)
  c
}

lote <- c("d1", "d2", "d3", "d4", "b1", "b2", "b3", "b4", "b5", "b6")

# Espao amostral
esp <- matrix("x", 100, 2)
k <- 1
for (i in 1:10) {
    for (j in 1:10) {
        esp[k, 1] <- lote[i]
        esp[k, 2] <- lote[j]
        k <- k + 1
    }
}

# Evento A
A <- matrix("x", 60, 2)
k <- 1
for (i in 1:6) {
    for (j in 1:10) {
        A[k, 1] <- lote[4 + i]
        A[k, 2] <- lote[j]
        k <- k + 1
    }
}
A

# Evento B
B <- matrix("x", 60, 2)
k <- 1
for (i in 1:10) {
    for (j in 1:6) {
        B[k, 1] <- lote[i]
        B[k, 2] <- lote[4 + j]
        k <- k + 1
    }
}
B

# Calculo de P(A/B)
PC(A, B)

# Calculo de P(B)
PC(B, esp)
