#===============================================================================
#. Name   : Frequncia relativa vs. densidade
# Author : J.C.Faria
# Date   : 2023-12-19 17:19:32
# Aim    : Possibilitar o entendimento da diferena entre
#          Frequncia relativa e desidade de probabilidades
# Mail   : <<<joseclaudio.faria@gmail.com>>>
#===============================================================================
# Sntese: Essencialmente, o conceito de densidade de probabilidades (DP)
#          elimina a influncia da amplitude de classes (h) no grfico da
#          frequncia relativa (FR).

#          Esta, como se sabe, descreve - em termos relativos (fi/total) -
#          todas as frequncias dos fenmenos observacionais.

#          Os dois conceitos (DP e FR) tem o mesmo siginificado apenas quando
#          a amplitude de classes (h)  igual a 1.

#          A DP possibilita a generalizao do conceito descritivo simples
#          da FR para os fenmenos observacionais genricos atravz do uso
#          das funes de densidade de probabilidades j bem estudadas e
#          consolidados: Normal, t de Student, F de Snedecor, etc.
#===============================================================================
#. Pacote necessrio
library(fdth)

#. Um exerccio de percepo
set.seed(2019)
amo <- rnorm(n=1e4,
             m=10,
             sd=2)
range(amo)

(tb <- fdt(amo,
           start=0,
           end=20,
           h=20))

par(mfrow=c(3, 1))
plot(tb,
     type='rfh',
     ylab='Freq. relativa (fr)',
     ylim=c(0, 1))     #.. <--- Observar!
text(x=10,
     y=.4,
     label= 'rea = 20')

plot(tb,
     type='d',
     ylab='Densidade (d)',
     ylim=c(0, 1))     #.. <--- Observar!
text(x=10,
     y=.4,
     label= 'rea = 1')

plot(tb,
     type='d',
     ylab='Densidade (d)',
     ylim=c(0, 1/20))  #.. <--- Observar!
text(x=10,
     y=.02,
     label= 'rea = 1')

#. Simulao
#.. Definindo valores
# (Ajuste, se necessrio, para obter uma boa visualizao)
m  <- 5      #.. mdia
s  <- 2      #.. desvio padro (1 =< s <= 8)
n  <- 1e4    #.. tamanho da amostra
st <- m-4*s  #.. Primmeira classe do histograma
en <- m+4*s  #.. ltima classe do histograma

# ylm determinado - experimentalmente - para os intervalos vlidos de 's'
ylm <- c(0,
         0.69 - 0.19*s + 0.015*s^2)

# Lista de controle da simulao
L <- list(s1=letters[1:3],

          s2=seq(from=.5,
                 to=1.5,
                 by=.5),

          s3=c('rfh',
               'd'),

          s4=c('Freq. relativa (fr)',
               'Densitdade (d)'),

          s5=c('h=0.5 | fr < d',
               'h=1.0 | fr = d',
               'h=1.5 | fr > d',
               'h=0.5 | fr < d',
               'h=1.0 | fr = d',
               'h=1.5 | fr > d'))

par(mfrow=c(2, 3))  # duas linhas e duas colunas com preencimento nas linhas

for(i in 1:2) {   # i: linhas
  for(j in 1:3) { # j: colunas
    plot(fdt(rnorm(n=n,
                   m=m,
                   sd=s),
             start=st,
             end=en,
             h=L$s2[j]),  #.. <--- Observar!
         type=L$s3[i],    #.. <--- Observar!
         xlab='',
         xlim=c(st,
                en),
         ylim=ylm,
         ylab=switch(L$s1[i],
                     a=L$s4[1],
                     b=L$s4[2]),
         main=ifelse(i == 1,
                switch(L$s1[j],
                       a=L$s5[1],
                       b=L$s5[2],
                       c=L$s5[3]),
                switch(L$s1[j],
                       a=L$s5[4],
                       b=L$s5[5],
                       c=L$s5[6])))

    # Plotando a curva de densidade correspondente
    curve(dnorm(x,
                m=m,
                sd=s),
          add=T,
          lw=3,
          col=2,
          n=1e3)
  }
}
